Client

Struct Client 

pub struct Client { /* private fields */ }
An synchronous OSS client which requesting aliyun OSS api in blocking mode.

Implementations

Source

impl Client

pub fn presign_url<S1, S2>( &self, bucket_name: S1, object_key: S2, options: PresignGetOptions, ) -> String
where S1: AsRef<str>, S2: AsRef<str>,

Presign URL for GET request without any additional headers supported, for brower mostly

pub fn presign_raw_request(&self, oss_request: OssRequest) -> SignedOssRequest

Source

impl Client

pub fn from_env() -> Self

Creates a new client from environment variables.

  • ALI_ACCESS_KEY_ID The access key id
  • ALI_ACCESS_KEY_SECRET The access key secret
  • ALI_OSS_ENDPOINT The endpoint of the OSS service. e.g. oss-cn-hangzhou.aliyuncs.com. Or, you can write full URL http://oss-cn-hangzhou.aliyuncs.com or https://oss-cn-hangzhou.aliyuncs.com with scheme http or https.
  • ALI_OSS_REGION Optional. The region of the OSS service. If not present, It will be inferred from the ALI_OSS_ENDPOINT env.
pub fn new<S1, S2, S3, S4>( access_key_id: S1, access_key_secret: S2, region: S3, endpoint: S4, ) -> Self
where S1: AsRef<str>, S2: AsRef<str>, S3: AsRef<str>, S4: AsRef<str>,

pub fn clone_to<S1, S2>(&self, region: S1, endpoint: S2) -> Self
where S1: AsRef<str>, S2: AsRef<str>,

Clone a new client instance with the same security data and different region. This is helpful if you are operation on buckets across multiple regions with a single pair of access key id and secret.