pub struct ClientBuilder { /* private fields */ }Expand description
Builder for Client.
Implementations
Sourceimpl ClientBuilder
impl ClientBuilder
Sourcepub fn new<S1, S2, S3>(
access_key_id: S1,
access_key_secret: S2,
endpoint: S3,
) -> Self
pub fn new<S1, S2, S3>( access_key_id: S1, access_key_secret: S2, endpoint: S3, ) -> Self
endpoint could be: oss-cn-hangzhou.aliyuncs.com without scheme part.
or you can include scheme part in the endpoint: https://oss-cn-hangzhou.aliyuncs.com.
if no scheme specified, use https by default.
Sourcepub fn region(self, region: impl Into<String>) -> Self
pub fn region(self, region: impl Into<String>) -> Self
Set region id explicitly. e.g. cn-beijing, cn-hangzhou.
CAUTION no oss- prefix for region.
If no region is set, I will be guessed from endpoint.