pub enum PutObjectResult {
ApiResponse(PutObjectApiResponse),
CallbackResponse(String),
}Expand description
Put object result enumeration
Variants
ApiResponse(PutObjectApiResponse)
This is response headers from aliyun oss api when you put object with no callback specified
CallbackResponse(String)
This is your callback response content string when you put object with callback specified.
.0 should be a valid JSON string.