pub struct Client { /* private fields */ }Expand description
An asynchronous OSS client.
Implementations
Sourceimpl Client
impl Client
Sourcepub fn presign_url<S1, S2>(
&self,
bucket_name: S1,
object_key: S2,
options: PresignGetOptions,
) -> String
pub fn presign_url<S1, S2>( &self, bucket_name: S1, object_key: S2, options: PresignGetOptions, ) -> String
Presign URL for GET request without any additional headers supported, for browser mostly
Sourcepub fn presign_raw_request(&self, oss_request: OssRequest) -> SignedOssRequest
pub fn presign_raw_request(&self, oss_request: OssRequest) -> SignedOssRequest
Presign a raw request, get the url and headers which contain calculated signature. So you can use the url and headers in other applications, frameworks or languages to complete the request.
Examples
Get the presigned url and headers using ali-oss-rs crate.
let client = Client::from_env();
let object = format!("rust-sdk-test/{}.webp", Uuid::new_v4());
let request = OssRequest::new()
.method(RequestMethod::Put)
.bucket("yuanyq")
.object(&object)
.add_header("content-type", "image/webp")
.add_header("content-length", "36958");
let SignedOssRequest {url, headers} = client.presign_raw_request(request);
log::debug!("{} {:#?}", url, headers);You will get the headers includes calculated authorization string. Then copy the url and headers to your javascript code which sending HTTP request using Axios:
const Axios = require("axios");
const fs = require("fs");
const axios = Axios.create();
(async function() {
const filePath = "/home/yuanyq/Pictures/test-8.webp";
const fileStream = fs.createReadStream(filePath);
const response = await axios.request({
method: "PUT",
url: "https://yuanyq.oss-cn-beijing.aliyuncs.com/rust-sdk-test/xxxxx.webp",
headers: {
"content-type": "image/webp",
"authorization": "OSS4-HMAC-SHA256 Credential=LTAIxxxxxxpeA/20250228/cn-beijing/oss/aliyun_v4_request,Signature=xxxxx",
"x-oss-content-sha256": "UNSIGNED-PAYLOAD",
"x-sdk-client": "ali-oss-rs/0.1.3",
"x-oss-date": "20250228T074254Z",
"content-length": "36958",
},
data: fileStream
});
console.log(response);
})();Sourceimpl Client
impl Client
Sourcepub fn from_env() -> Self
pub fn from_env() -> Self
Creates a new client from environment variables.
ALI_ACCESS_KEY_IDThe access key idALI_ACCESS_KEY_SECRETThe access key secretALI_OSS_ENDPOINTThe endpoint of the OSS service. e.g.oss-cn-hangzhou.aliyuncs.com. Or, you can write full URLhttp://oss-cn-hangzhou.aliyuncs.comorhttps://oss-cn-hangzhou.aliyuncs.comwith schemehttporhttps.ALI_OSS_REGIONOptional. The region id of the OSS service e.g.cn-hangzhou,cn-beijing. If not present, It will be inferred fromALI_OSS_ENDPOINTenv.
Sourcepub fn new<S1, S2, S3, S4>(
access_key_id: S1,
access_key_secret: S2,
region: S3,
endpoint: S4,
) -> Self
pub fn new<S1, S2, S3, S4>( access_key_id: S1, access_key_secret: S2, region: S3, endpoint: S4, ) -> Self
Create a new client.
See Self::from_env for more details about the arguments.
If you need highly cusomtized reqwest::Client to setup this struct,
Please check ClientBuilder